@@ -62,5 +62,5 @@ def callback(process, filename):
     
     
 if __name__ == '__main__':
-    # res = ssh_download_file('/root/nav_ws/src/lidar_localization/Localization/data/latest/finalCloud.pcd', './', '10.10.8.156', 'root', '123456', 5000, callback)
-    threading.Thread(target=ssh_download_file, args=('/root/nav_ws/src/lidar_localization/Localization/data/latest/finalCloud.pcd', './', '10.10.8.156', 'root', '123456', 5000, callback,)).start()
\ No newline at end of file
+    res = ssh_download_file('/root/nav_ws/src/lidar_localization/Localization/data/latest/finalCloud.pcd', './', '10.10.11.10', 'root', '123456', 5000, callback)
+    threading.Thread(target=ssh_download_file, args=('/root/nav_ws/src/lidar_localization/Localization/data/latest/', './', '10.10.11.10', 'root', '123456', 5000, callback,)).start()
\ No newline at end of file
