@@ -125,6 +125,7 @@ class CreateDevice:
             self.imageFocus_url = '%s/ISAPI/Image/channels/1/focusConfiguration' % self._base
             self.ptz_capabilities_url = '%s/ISAPI/PTZCtrl/capabilities' % self._base
             self.ptz_autopan_url = '%s/ISAPI/PTZCtrl/channels/1/autopan' % self._base
+            self.streamParam_url = '%s/ISAPI/Thermal/channels/2/streamParam' % self._base
 
         else:
             self.motion_url = '%s/MotionDetection/1' % self._base
@@ -564,6 +565,61 @@ class CreateDevice:
             return None
         return None
     
+    def get_streamParam(self, element_to_query=None):
+        response = requests.get(
+            self.streamParam_url,
+            auth=self._auth_fn(self._username, self._password),
+            )
+        if response.status_code != 200:
+            return None
+
+        if element_to_query is None:
+            return response.text
+        try:
+            tree = tree_no_ns_from_string(response.text)
+
+            element_to_query = './/%s%s' % (
+                self._xml_namespace, element_to_query)
+            result = tree.findall(element_to_query)
+            if len(result) > 0:
+                return result[0].text.strip()
+            
+
+        except AttributeError as attib_err:
+            
+            return None
+        return None
+    
+    # 配置指定通道热成像码流参数 videoCodingType:thermal_raw_data#热成像裸数据,pixel-to-pixel_thermometry_data#全屏测温数据,real-time_raw_data#实时裸数据,spectrogramData#科学仪器谱图数据（包括检测物质中的光谱波长与能量值） 
+    def set_streamParam(self, element_to_query=None, videoCodingType='pixel-to-pixel_thermometry_data'):
+        data_xml = '<?xml version: "1.0" encoding="UTF-8"?><ThermalStreamParam xmlns="http://www.isapi.org/ver20/XMLSchema" version="2.0">' +\
+            '<videoCodingType>'+ str(videoCodingType) +'</videoCodingType>' +\
+            '</ThermalStreamParam>'
+            
+        print(data_xml)
+            
+        response = requests.put(
+            self.streamParam_url,
+            auth=self._auth_fn(self._username, self._password),
+            data=data_xml,
+            )
+        if response.status_code != 200:
+            return None
+
+        if element_to_query is None:
+            return response.text
+        try:
+            tree = tree_no_ns_from_string(response.text)
+
+            element_to_query = './/%s%s' % (
+                self._xml_namespace, element_to_query)
+            result = tree.findall(element_to_query)
+            if len(result) > 0:
+                return result[0].text.strip()
+        except AttributeError as attib_err:
+            return None
+        return None
+    
     def get_version(self):
         """
         Returns the firmware version running on the camera
